@@ -1,25 +1,12 @@
 /*
- * Softimage PIC support for QImage.
- *
- * Copyright 1998 Halfdan Ingvarsson
- * Copyright 2007 Ruben Lopez <r.lopez@bren.es>
- * Copyright 2014 Alex Merry <alex.merry@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- * ----------------------------------------------------------------------------
- */
+    Softimage PIC support for QImage.
+
+    SPDX-FileCopyrightText: 1998 Halfdan Ingvarsson
+    SPDX-FileCopyrightText: 2007 Ruben Lopez <r.lopez@bren.es>
+    SPDX-FileCopyrightText: 2014 Alex Merry <alex.merry@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 /* This code is based on the GIMP-PIC plugin by Halfdan Ingvarsson,
  * and relicensed from GPL to LGPL to accommodate the KDE licensing policy
@@ -253,6 +240,11 @@ bool SoftimagePICHandler::read(QImage *image)
     }
 
     QImage img(m_header.width, m_header.height, fmt);
+    if (img.isNull()) {
+        qDebug() << "Failed to allocate image, invalid dimensions?" << QSize(m_header.width, m_header.height) << fmt;
+        return false;
+    }
+
     img.fill(qRgb(0,0,0));
 
     for (int y = 0; y < m_header.height; y++) {
@@ -362,6 +354,7 @@ bool SoftimagePICHandler::readHeader()
             m_state = ReadHeader;
         }
     }
+
     return m_state != Error;
 }
 
